import React,{FunctionComponent} from 'react';
import {Box, Slide } from '@mui/material';

export type PushSubscriptionDialogProps = {
    open: boolean;
    onAccept?: () => void;
    onDecline?: () => void;
    image?: string;
    title?: string;
    content: string;
}

const BUTTON_SX = {
    fontSize: '16px',
    lineHeight: 1.5,
    display: 'inline-flex',
    alignItems: 'center',
    padding: '6px 16px',
    borderRadius: '4px',
    border: 0,
    cursor: 'pointer',
    height: '42px',
    verticalAlign: 'middle',
    margin: 0,
    fontWeight: 400,
};

const PushSubscriptionDialog: FunctionComponent<PushSubscriptionDialogProps> = ({
    content,
    image,
    onAccept,
    onDecline,
    open,
    title
}) => {
    return (
        <Slide in={open} direction={'down'}>
            <Box sx={{
                position: 'fixed',
                top: 0,
                left: 0,
                width: '100%',
                height: '100%',
                justifyContent: 'center',
                zIndex: 100,
            }}>
                <Box sx={{
                    margin: '0 auto',
                    borderBottomLeftRadius: '.4em',
                    borderBottomRightRadius: '.4em',
                    maxWidth: '500px',
                    padding: '22px',
                    backgroundColor: '#fff',
                    boxShadow: '0 1px 3px rgba(0,0,0,.03),0 2px 32px rgba(0,0,0,.1)',
                }}>
                    <Box sx={{ display: 'flex', marginBottom: '5px'}}>
                        {image && (
                            <img style={{
                                marginRight: '16px',
                                width: '80px',
                                height: 'auto',
                            }} src={image} alt={''} />
                        )}
                        <div>
                            {title && <Box sx={{ fontWeight: 500, marginBottom: '5px' }}>{title}</Box>}
                            <div>{content}</div>
                        </div>
                    </Box>

                    <Box sx={{ display: 'flex', justifyContent: 'flex-end' }}>
                        <button style={{
                            ...BUTTON_SX,
                            marginRight: '16px',
                            backgroundColor: 'transparent',
                        }} onClick={onDecline}>Ne, hvala</button>

                        <button style={{
                            ...BUTTON_SX,
                            backgroundColor: '#2583e3',
                            color: '#fff',
                        }} onClick={onAccept}>Naravno</button>
                    </Box>
                </Box>
            </Box>
        </Slide>
    );
}

export default PushSubscriptionDialog;
