import {useEffect, useState} from 'react';

const useServiceWorker = (): ServiceWorkerRegistration|null => {
    if (!('serviceWorker' in navigator)) {
        console.warn('No service worker support.');
        return null;
    }

    const [registration, setRegistration] = useState<ServiceWorkerRegistration|null>(null);

    useEffect(() => {
        navigator.serviceWorker.register('/sw.js')
            .then(reg => {
                setRegistration(reg);
                return reg;
            })
            .catch(err => {
                console.error('Error while registering the service worker.', err);
            });
    }, []);

    return registration;
};

export default useServiceWorker;
