<?php
declare(strict_types=1);

namespace Tiara\Push\Handler\Subscription;

use Laminas\Diactoros\Response\EmptyResponse;
use Laminas\Diactoros\Response\JsonResponse;
use Laminas\Diactoros\Response\TextResponse;
use Psr\Http\Message\ResponseInterface;
use Psr\Http\Message\ServerRequestInterface;
use Psr\Http\Server\RequestHandlerInterface;
use Throwable;
use Tiara\Push\Service\SubscriptionManagerInterface;

/**
 * Class SaveSubscription
 *
 * @package Tiara\Push\Handler\Subscription
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/tiara-push
 */
final class Save implements RequestHandlerInterface
{
    private SubscriptionManagerInterface $subscriptions;

    /**
     * @param SubscriptionManagerInterface $subscriptions
     */
    public function __construct(SubscriptionManagerInterface $subscriptions)
    {
        $this->subscriptions = $subscriptions;
    }

    /**
     * @param ServerRequestInterface $request
     * @return ResponseInterface
     */
    public function handle(ServerRequestInterface $request): ResponseInterface
    {
        $subscription = json_decode($request->getBody()->getContents(), true);

        $endpoint = $subscription['endpoint'] ?? '';
        $keys = $subscription['keys'] ?? [];

        try {
            $this->subscriptions->save($endpoint, $keys);
        } catch (Throwable $e) {
            return new TextResponse($e->getMessage(), 400);
        }

        return new EmptyResponse(201);
    }
}