<?php
declare(strict_types=1);

namespace Tiara\Push\Middleware;

use Laminas\Stratigility\Middleware\PathMiddlewareDecorator;
use Laminas\Stratigility\MiddlewarePipe;
use Laminas\Stratigility\MiddlewarePipeInterface;
use Mezzio\Middleware\LazyLoadingMiddleware;
use Mezzio\MiddlewareContainer;
use Psr\Container\ContainerInterface;
use Tiara\Push\Handler\Subscription\Save;

/**
 * Class PushMiddlewareFactory
 *
 * @package Tiara\Push\Middleware
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/tiara-push
 */
final class PushMiddlewareFactory
{
    public function __invoke(ContainerInterface $container): MiddlewarePipeInterface
    {
        $middleware = new MiddlewarePipe();
        $middlewareContainer = new MiddlewareContainer($container);

        $middleware->pipe(
            new PathMiddlewareDecorator(
                '/subscriptions',
                new RequestMethodDecorator(
                    'POST',
                    new LazyLoadingMiddleware($middlewareContainer, Save::class)
                )
            )
        );

        return $middleware;
    }
}