<?php
declare(strict_types=1);

namespace Tiara\Push\Service;

use Doctrine\DBAL\Connection;
use Doctrine\DBAL\Exception as DBALException;
use RuntimeException;

/**
 * Class SubscriptionManager
 *
 * @package Tiara\Push\Service
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/tiara-push
 */
final class SubscriptionManager implements SubscriptionManagerInterface
{
    private Connection $conn;

    /**
     * @param Connection $conn
     */
    public function __construct(Connection $conn)
    {
        $this->conn = $conn;
    }

    /**
     * @param string $endpoint
     * @param array $keys
     * @throws DBALException
     */
    public function save(string $endpoint, array $keys): void
    {
        if (empty($endpoint) || empty($keys)) {
            throw new RuntimeException('Invalid subscription.');
        }

        if (!$this->exists($endpoint)) {
            $this->conn->insert('push_subscriptions', [
                'id' => md5($endpoint),
                'endpoint' => $endpoint,
                'auth_keys' => json_encode($keys),
            ]);
        }
    }

    /**
     * @param string $endpoint
     * @return bool
     * @throws DBALException
     */
    private function exists(string $endpoint): bool
    {
        $id = md5($endpoint);
        $sql = 'SELECT 1 FROM push_subscriptions WHERE id = ?';

        $stmt = $this->conn->executeQuery($sql, [$id]);

        return $stmt->rowCount() > 0;
    }
}