<?php
declare(strict_types=1);

namespace Tiara\Push\Service;

use Doctrine\DBAL\Connection;
use Psr\Container\ContainerInterface;
use RuntimeException;

/**
 * Class SubscriptionManagerFactory
 *
 * @package Tiara\Push\Service
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/tiara-push
 */
final class SubscriptionManagerFactory
{
    /**
     * @param ContainerInterface $container
     * @return SubscriptionManagerInterface
     */
    public function __invoke(ContainerInterface $container): SubscriptionManagerInterface
    {
        $config = $container->get('config')['push'] ?? [];

        if (!isset($config['connection']) || empty($config['connection'])) {
            throw new RuntimeException('Connection key not set.');
        }

        if (!$container->has($config['connection'])) {
            throw new RuntimeException(sprintf(
                'Connection %s not found in the container.',
                $config['connection']
            ));
        }

        $conn = $container->get($config['connection']);

        if (!$conn instanceof Connection) {
            throw new RuntimeException(sprintf(
                'Invalid connection, %s expected and got %s.',
                Connection::class,
                is_object($conn) ? get_class($conn) : gettype($conn)
            ));
        }

        return new SubscriptionManager($conn);
    }
}